@@ -8,6 +8,7 @@ BEGIN { our @ISA = 'App::Cmd::ArgProcessor' };
 
 use File::Basename ();
 use Module::Pluggable::Object ();
+use Text::Abbrev;
 
 use Sub::Exporter -setup => {
   collectors => {
@@ -47,11 +48,11 @@ App::Cmd - write command line apps with less suffering
 
 =head1 VERSION
 
-version 0.014_02
+version 0.299_01
 
 =cut
 
-our $VERSION = '0.014_02';
+our $VERSION = '0.299_01';
 
 =head1 SYNOPSIS
 
@@ -176,6 +177,12 @@ sub _command {
 
   $self->_load_default_plugin($_, $arg, \%plugin) for qw(commands help);
 
+  if ($self->allow_any_unambiguous_abbrev) {
+    # add abbreviations to list of authorized commands
+    my %abbrev = abbrev keys %plugin;
+    @plugin{ keys %abbrev } = @plugin{ values %abbrev };
+  }
+
   return \%plugin;
 }
 
@@ -281,6 +288,11 @@ Then the methods return:
 These values are captured when the App::Cmd object is created, so it is safe to
 assign to C<$0> later.
 
+=cut
+
+sub arg0      { $_[0]->{arg0} }
+sub full_arg0 { $_[0]->{full_arg0} }
+
 =head2 prepare_command
 
   my ($cmd, $opt, @args) = $app->prepare_command(@ARGV);
@@ -357,7 +369,7 @@ sub execute_command {
   local our $active_cmd = $cmd;
 
   $cmd->validate_args($opt, \@args);
-  $cmd->run($opt, \@args);
+  $cmd->execute($opt, \@args);
 }
 
 =head2 plugin_search_path
@@ -400,6 +412,23 @@ sub plugin_search_path {
   }
 }
 
+=head2 allow_any_unambiguous_abbrev
+
+If this method returns true (which, by default, it does I<not>), then any
+unambiguous abbreviation for a registered command name will be allowed as a
+means to use that command.  For example, given the following commands:
+
+  reticulate
+  reload
+  rasterize
+
+Then the user could use C<ret> for C<reticulate> or C<ra> for C<rasterize> and
+so on.
+
+=cut
+
+sub allow_any_unambiguous_abbrev { return 0 }
+
 =head2 global_options
 
   if ($cmd->app->global_options->{verbose}) { ... }
