@@ -11,23 +11,28 @@ App::Cmd::Command::help - display a command's help screen
 
 =head1 VERSION
 
-version 0.014_02
+version 0.299_01
 
 =cut
 
-our $VERSION = '0.014_02';
+our $VERSION = '0.299_01';
 
 =head1 DESCRIPTION
 
 This command plugin implements a "help" command.  This command will either list
 all of an App::Cmd's commands and their abstracts, or display the usage screen
-for a subcommand.
+for a subcommand with its description.
 
 =cut
 
-
 sub command_names { qw/help --help -h -?/ }
 
+sub description {
+"This command will either list all of the application commands and their
+abstracts, or display the usage screen for a subcommand with its
+description.\n"
+}
+
 sub run {
   my ($self, $opts, $args) = @_;
 
@@ -51,7 +56,17 @@ sub run {
     $self->app->execute_command( $self->app->_prepare_command("commands") );
   } else {
     my ($cmd, $opt, $args) = $self->app->prepare_command(@$args);
-    print $cmd->_usage_text;
+
+    local $@;
+    my $desc = $cmd->description;
+    $desc = "\n$desc" if length $desc;
+
+    my $ut = join "\n",
+      eval { $cmd->usage->leader_text },
+      $desc,
+      eval { $cmd->usage->option_text };
+
+    print $ut;
   }
 }
 
